==> jc-1.4.0.tar.gz: javax/swing/plaf/PopupMenuUI.h <==
// public abstract class javax.swing.plaf.PopupMenuUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class e033d82fb74753d9 javax_swing_plaf_PopupMenuUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_PopupMenuUI_H_
#define _JC_javax_swing_plaf_PopupMenuUI_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JPopupMenu$object;
struct _jc_javax_swing_Popup$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_PopupMenuUI$sub_refs	_jc_javax_swing_plaf_PopupMenuUI$sub_refs;
typedef struct _jc_javax_swing_plaf_PopupMenuUI$sub_nonrefs	_jc_javax_swing_plaf_PopupMenuUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_PopupMenuUI$refs	_jc_javax_swing_plaf_PopupMenuUI$refs;
typedef struct _jc_javax_swing_plaf_PopupMenuUI$nonrefs	_jc_javax_swing_plaf_PopupMenuUI$nonrefs;
typedef struct _jc_javax_swing_plaf_PopupMenuUI$object	_jc_javax_swing_plaf_PopupMenuUI$object;

typedef const struct _jc_javax_swing_plaf_PopupMenuUI$vmethods	_jc_javax_swing_plaf_PopupMenuUI$vmethods;
typedef const struct _jc_javax_swing_plaf_PopupMenuUI$vtable	_jc_javax_swing_plaf_PopupMenuUI$vtable;
typedef const struct _jc_javax_swing_plaf_PopupMenuUI$vtype	_jc_javax_swing_plaf_PopupMenuUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_PopupMenuUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_PopupMenuUI$object *);

// Virtual methods
extern struct _jc_javax_swing_Popup$object *_jc_javax_swing_plaf_PopupMenuUI$method$getPopup$7814f6262a491c6c(_jc_env *, struct _jc_javax_swing_plaf_PopupMenuUI$object *, struct _jc_javax_swing_JPopupMenu$object *, jint, jint);
extern jboolean _jc_javax_swing_plaf_PopupMenuUI$method$isPopupTrigger$4c3c19074873084a(_jc_env *, struct _jc_javax_swing_plaf_PopupMenuUI$object *, struct _jc_java_awt_event_MouseEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_PopupMenuUI$method_info$getPopup$7814f6262a491c6c;
extern _jc_method _jc_javax_swing_plaf_PopupMenuUI$method_info$isPopupTrigger$4c3c19074873084a;

// Virtual methods structure
struct _jc_javax_swing_plaf_PopupMenuUI$vmethods {
	struct _jc_javax_swing_Popup$object	*(*getPopup$7814f6262a491c6c)(_jc_env *, struct _jc_javax_swing_plaf_PopupMenuUI$object *, struct _jc_javax_swing_JPopupMenu$object *, jint, jint);
	jboolean	(*isPopupTrigger$4c3c19074873084a)(_jc_env *, struct _jc_javax_swing_plaf_PopupMenuUI$object *, struct _jc_java_awt_event_MouseEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_PopupMenuUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_PopupMenuUI$vmethods	javax_swing_plaf_PopupMenuUI;
};

// Vtype
struct _jc_javax_swing_plaf_PopupMenuUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_PopupMenuUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_PopupMenuUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_PopupMenuUI$refs {
    _jc_javax_swing_plaf_PopupMenuUI$sub_refs	javax_swing_plaf_PopupMenuUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_PopupMenuUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_PopupMenuUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_PopupMenuUI$sub_nonrefs	javax_swing_plaf_PopupMenuUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_PopupMenuUI$object {
	_jc_javax_swing_plaf_PopupMenuUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_PopupMenuUI$vtype	*vtype;
	_jc_javax_swing_plaf_PopupMenuUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_PopupMenuUI$vtype _jc_javax_swing_plaf_PopupMenuUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_PopupMenuUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_PopupMenuUI$class_object;

#endif	/* _JC_javax_swing_plaf_PopupMenuUI_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/PopupMenuUI.h <==
// public abstract class javax.swing.plaf.PopupMenuUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class e033d82fb74753d9 javax_swing_plaf_PopupMenuUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_PopupMenuUI_H_
#define _JC_javax_swing_plaf_PopupMenuUI_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JPopupMenu$object;
struct _jc_javax_swing_Popup$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_PopupMenuUI$sub_refs	_jc_javax_swing_plaf_PopupMenuUI$sub_refs;
typedef struct _jc_javax_swing_plaf_PopupMenuUI$sub_nonrefs	_jc_javax_swing_plaf_PopupMenuUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_PopupMenuUI$refs	_jc_javax_swing_plaf_PopupMenuUI$refs;
typedef struct _jc_javax_swing_plaf_PopupMenuUI$nonrefs	_jc_javax_swing_plaf_PopupMenuUI$nonrefs;
typedef struct _jc_javax_swing_plaf_PopupMenuUI$object	_jc_javax_swing_plaf_PopupMenuUI$object;

typedef const struct _jc_javax_swing_plaf_PopupMenuUI$vmethods	_jc_javax_swing_plaf_PopupMenuUI$vmethods;
typedef const struct _jc_javax_swing_plaf_PopupMenuUI$vtable	_jc_javax_swing_plaf_PopupMenuUI$vtable;
typedef const struct _jc_javax_swing_plaf_PopupMenuUI$vtype	_jc_javax_swing_plaf_PopupMenuUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_PopupMenuUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_PopupMenuUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_Popup$object *_jc_javax_swing_plaf_PopupMenuUI$method$getPopup$7814f6262a491c6c(_jc_env *, struct _jc_javax_swing_plaf_PopupMenuUI$object *, struct _jc_javax_swing_JPopupMenu$object *, jint, jint) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_plaf_PopupMenuUI$method$isPopupTrigger$4c3c19074873084a(_jc_env *, struct _jc_javax_swing_plaf_PopupMenuUI$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_PopupMenuUI$method_info$getPopup$7814f6262a491c6c;
extern _jc_method _jc_javax_swing_plaf_PopupMenuUI$method_info$isPopupTrigger$4c3c19074873084a;

// Virtual methods structure
struct _jc_javax_swing_plaf_PopupMenuUI$vmethods {
	struct _jc_javax_swing_Popup$object	*(*getPopup$7814f6262a491c6c)(_jc_env *, struct _jc_javax_swing_plaf_PopupMenuUI$object *, struct _jc_javax_swing_JPopupMenu$object *, jint, jint) _JC_JCNI_ATTR;
	jboolean	(*isPopupTrigger$4c3c19074873084a)(_jc_env *, struct _jc_javax_swing_plaf_PopupMenuUI$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_PopupMenuUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_PopupMenuUI$vmethods	javax_swing_plaf_PopupMenuUI;
};

// Vtype
struct _jc_javax_swing_plaf_PopupMenuUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_PopupMenuUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_PopupMenuUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_PopupMenuUI$refs {
    _jc_javax_swing_plaf_PopupMenuUI$sub_refs	javax_swing_plaf_PopupMenuUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_PopupMenuUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_PopupMenuUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_PopupMenuUI$sub_nonrefs	javax_swing_plaf_PopupMenuUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_PopupMenuUI$object {
	_jc_javax_swing_plaf_PopupMenuUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_PopupMenuUI$vtype	*vtype;
	_jc_javax_swing_plaf_PopupMenuUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_PopupMenuUI$vtype _jc_javax_swing_plaf_PopupMenuUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_PopupMenuUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_PopupMenuUI$class_object;

#endif	/* _JC_javax_swing_plaf_PopupMenuUI_H_ */
